@@ -2,7 +2,7 @@ package Bread::Board;
 BEGIN {
   $Bread::Board::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::VERSION = '0.32';
+$Bread::Board::VERSION = '0.33';
 use strict;
 use warnings;
 use Carp qw(confess);
@@ -33,6 +33,7 @@ Moose::Exporter->setup_import_methods(
         include
         typemap
         infer
+        literal
     ]],
 );
 
@@ -238,6 +239,15 @@ sub depends_on ($) {
     Bread::Board::Dependency->new(service_path => $path);
 }
 
+my $LITERAL_ANON = 0;
+sub literal($) {
+    my $value = shift;
+    Bread::Board::Literal->new(
+        name => 'LITERAL_ANON_' . $LITERAL_ANON++,
+        value => $value,
+    );
+}
+
 1;
 
 __END__
@@ -252,7 +262,7 @@ Bread::Board - A solderless way to wire up your application components
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -361,9 +371,11 @@ Bread::Board configuration. You can build such a configuration by constructing
 the objects manually instead, but your code may be more difficult to
 understand.
 
-=over 4
+=head2 C<container>
 
-=item I<container ($name, &body)>
+=head3 simple case
+
+  container $name, \&body;
 
 This function constructs and returns an instance of L<Bread::Board::Container>.
 The (optional) C<&body> block may be used to add services or sub-containers
@@ -382,7 +394,9 @@ If C<$name> starts with C<'+'>, and the container is being declared inside
 another container, then this declaration will instead extend an existing
 container with the name C<$name> (without the C<'+'>).
 
-=item I<container ($container_instance, &body)>
+=head3 from an instance
+
+  container $container_instance, \&body
 
 In many cases, subclassing L<Bread::Board::Container> is the easiest route to
 getting access to this framework. You can do this and still get all the
@@ -405,7 +419,9 @@ your class:
       };
   }
 
-=item I<container ($name, [ @parameters ], &body)>
+=head3 with parameters
+
+  container $name, \@parameters, \&body
 
 A third way of using the C<container> function is to build a parameterized
 container. These are useful as a way of providing a placeholder for parts of
@@ -415,23 +431,32 @@ object in place of the C<$name> in this case.
 For more detail on how you might use parameterized containers, see
 L<Bread::Board::Manual::Concepts::Advanced/Parameterized Containers>.
 
-=item I<as (&body)>
+=head2 C<as>
+
+  as { some_code() };
 
 This is just a replacement for the C<sub> keyword that is easier to read when
 defining containers.
 
-=item I<service ($name, $literal | %service_description)>
+=head2 C<service>
+
+  service $name, $literal;
+  service $name, %service_description;
 
 Within the C<as> blocks for your containers, you may construct services using
 the C<service> function. This can construct several different kinds of services
 based upon how it is called.
 
+=head3 literal services
+
 To build a literal service (a L<Bread::Board::Literal> object), just specify a
 scalar value or reference you want to use as the literal value:
 
   # In case you need to adjust the gravitational constant of the Universe
   service gravitational_constant => 6.673E-11;
 
+=head3 using injections
+
 To build a service using one of the injection services, just fill in all the
 details required to use that sort of injection:
 
@@ -458,6 +483,8 @@ of these is present, constructor injection will be used with
 L<Bread::Board::ConstructorInjection> (and you must provide the C<class>
 option).
 
+=head3 service dependencies
+
 The C<dependencies> parameter takes a hashref of dependency names mapped to
 L<Bread::Board::Dependency> objects, but there are several coercions and sugar
 functions available to make specifying dependencies as easy as possible. The
@@ -517,6 +544,8 @@ which returns an arrayref containing the resolved values of those dependencies:
       # ...
   );
 
+=head3 inheriting and extending services
+
 If the C<$name> starts with a C<'+'>, the service definition will instead
 extend an existing service with the given C<$name> (without the C<'+'>). This
 works similarly to the C<has '+foo'> syntax in Moose. It is most useful when
@@ -527,12 +556,40 @@ the existing values, rather than overridden. Note that literal services can't
 be extended, because there's nothing to extend. You can still override them
 entirely by declaring the service name without a leading C<'+'>.
 
-=item I<depends_on ($service_path)>
+=head2 C<literal>
+
+  literal($value);
+
+Creates an anonymous L<Bread::Board::Literal> object with the given value.
+
+          service 'dbh' => (
+              block => sub {
+                  my $s = shift;
+                  require DBI;
+                  DBI->connect(
+                      $s->param('dsn'),
+                      $s->param('username'),
+                      $s->param('password'),
+                  ) || die "Could not connect";
+              },
+              dependencies => {
+                dsn      => literal 'dbi:SQLite:somedb',
+                username => literal 'foo',
+                password => literal 'password',
+
+              },
+          );
+
+=head2 C<depends_on>
+
+  depends_on($service_path);
 
 The C<depends_on> function creates a L<Bread::Board::Dependency> object for the
 named C<$service_path> and returns it.
 
-=item I<wire_names (@service_names)>
+=head2 C<wire_names>
+
+  wire_names(@service_names);
 
 This function is just a shortcut for passing a hash reference of dependencies
 into the service. It is not typically needed, since Bread::Board can usually
@@ -566,7 +623,10 @@ understand what you mean - these declarations are all equivalent:
       dependencies => [ qw(foo bar baz ) ],
   );
 
-=item I<typemap ($type, $service | $service_path)>
+=head2 C<typemap>
+
+  typemap $type, $service;
+  typemap $type, $service_path;
 
 This creates a type mapping for the named type. Typically, it is paired with
 the C<infer> call like so:
@@ -576,7 +636,10 @@ the C<infer> call like so:
 For more details on what type mapping is and how it works, see
 L<Bread::Board::Manual::Concepts::Typemap>.
 
-=item I<infer (?%hints)>
+=head2 C<infer>
+
+  infer;
+  infer(%hints);
 
 This is used with C<typemap> to help create the typemap inference. It can be
 used with no arguments to do everything automatically. However, in some cases,
@@ -592,7 +655,9 @@ this:
 For more details on what type mapping is and how it works, see
 L<Bread::Board::Manual::Concepts::Typemap>.
 
-=item I<include ($file)>
+=head2 C<include>
+
+  include $file;
 
 This is a shortcut for loading a Bread::Board configuration from another file.
 
@@ -604,12 +669,17 @@ The above is pretty much identical to running:
 
 However, you might find it more readable to use C<include>.
 
-=item I<alias ($service_name, $service_path, %service_description)>
+=head2 C<alias>
 
-This helper allows for the creation of service aliases, which allows you to
-define a service in one place and then reuse that service with a different name
-somewhere else. This is sort of like a symbolic link for services. Aliases will
-be resolved recursively, so an alias can alias an alias.
+  alias $service_name, $service_path, %service_description;
+
+This helper allows for the creation of L<service
+aliases|Bread::Board::Service::Alias>, which allows you to define a
+service in one place and then reuse that service with a different name
+somewhere else. This is sort of like a symbolic link for
+services. Aliases will be L<resolved
+recursively|Bread::Board::Traversable/fetch>, so an alias can alias an
+alias.
 
 For example,
 
@@ -619,15 +689,13 @@ For example,
 
   alias my_logger => 'file_logger';
 
-=back
-
 =head1 OTHER FUNCTIONS
 
 These are not exported, but might be helpful to you.
 
-=over 4
+=head2 C<set_root_container>
 
-=item I<set_root_container ($container)>
+  set_root_container $container;
 
 You may use this to set a top-level root container for all container
 definitions.
@@ -642,8 +710,6 @@ For example,
 
 Here the C<$config> container would be created as a sub-container of C<$app>.
 
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Daisuke Maki for his contributions and for really
@@ -656,6 +722,9 @@ it.
 Matt "mst" Trout, for finally coming up with the best name
 for this module.
 
+Gianni "dakkar" Ceccarelli for writing lots of documentation, and
+Net-a-Porter.com for paying his salary while he was doing it.
+
 =head1 ARTICLES
 
 L<Bread::Board is the right tool for this job|http://domm.plix.at/perl/2013_04_bread_board_is_the_right_rool_for_this_job.html>
@@ -677,19 +746,22 @@ Bread::Board is basically my re-write of IOC.
 
 =back
 
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to Github Issues.
-
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
