@@ -2,7 +2,7 @@ package Bread::Board::Container::Parameterized;
 BEGIN {
   $Bread::Board::Container::Parameterized::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Container::Parameterized::VERSION = '0.32';
+$Bread::Board::Container::Parameterized::VERSION = '0.33';
 use Moose;
 use Moose::Util 'find_meta';
 use Bread::Board::Container::FromParameterized;
@@ -114,49 +114,101 @@ Bread::Board::Container::Parameterized - A parameterized container
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
+This class implements a sort of container factory for L<Bread::Board>:
+a parameterized container is a, in practice, a function from a set of
+parameters (which must be containers) to an actual container. See
+L<Bread::Board::Manual::Example::FormSensible> for an example.
+
 =head1 ATTRIBUTES
 
-=over 4
+=head2 C<name>
 
-=item B<name>
+Read/write string, required. Every container needs a name, by which it
+can be referenced when L<fetching it|Bread::Board::Traversable/fetch>.
 
-=item B<allowed_parameter_names>
+=head2 C<allowed_parameter_names>
 
-=item B<container>
+Read-only arrayref of strings, required. These are the names of the
+containers that must be passed to L<< C<create>|create ( %params ) >>
+to get an actual container out of this parameterized object.
 
-=back
+=head2 C<container>
+
+This attribute holds the "prototype" container. Services inside it can
+depend on service paths that include the container names given in
+L</allowed_parameter_names>.
 
 =head1 METHODS
 
-=over 4
+=head2 C<add_service>
 
-=item B<create ( %params )>
+=head2 C<get_service>
 
-=item B<fetch>
-=item B<resolve>
+=head2 C<has_service>
 
-These two methods die, they are not appropriate, but are here for
-completeness.
+=head2 C<get_service_list>
 
-=back
+=head2 C<has_services>
 
-=head1 BUGS
+=head2 C<add_sub_container>
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+=head2 C<get_sub_container>
+
+=head2 C<has_sub_container>
+
+=head2 C<get_sub_container_list>
+
+=head2 C<has_sub_containers>
+
+All these methods are delegated to the "prototype" L</container>, so
+that this object can be defined as if it were a normal container.
+
+=head2 C<create>
+
+  my $container = $parameterized_container->create(%params);
+
+After checking that the keys of C<%params> are exactly the same
+strings that are present in L</allowed_parameter_names>, this method
+clones the prototype L</container>, adds the C<%params> to the clone
+as sub-containers, and returns the clone.
+
+If this was not a top-level container, the parent is also cloned, and
+the container clone is added to the parent clone.
+
+Please note that the container returned by this method does I<not>
+have the same name as the parameterized container, and that calling
+this method with different parameter values will return different
+containers, but all with the same name. It's probably a bad idea to
+instantiate a non-top-level parameterized container more than once.
+
+=head2 C<fetch>
+
+=head2 C<resolve>
+
+These two methods die, since services in a parameterized container
+won't usually resolve, and attempting to do so is almost always a
+mistake.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
