@@ -2,7 +2,7 @@ package Bread::Board::Dependency;
 BEGIN {
   $Bread::Board::Dependency::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Dependency::VERSION = '0.32';
+$Bread::Board::Dependency::VERSION = '0.33';
 use Moose;
 
 use Bread::Board::Service;
@@ -62,45 +62,68 @@ Bread::Board::Dependency
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
+This class holds the information for a dependency of a
+L<service|Bread::Board::Service::WithDependencies>. When L<resolving
+dependencies|Bread::Board::Service::WithDependencies/resolve_dependencies>,
+instances of this class will be used to access the services that will
+provide the depended-on values.
+
+This class consumes the L<Bread::Board::Traversable> role to retrieve
+services given their path.
+
+=head1 ATTRIBUTES
+
+=head2 C<service_path>
+
+The path to use (possibly relative to the dependency itself) to access
+the L</service>.
+
+=head2 C<service>
+
+The service this dependency points at. Usually built lazily from the
+L</service_path>, but could just be passed in to the constructor.
+
+=head2 C<service_name>
+
+Name of the L</service>, defaults to the last element of the
+L</service_path>.
+
 =head1 METHODS
 
-=over 4
+=head2 C<has_service_path>
 
-=item B<get>
+Predicate for the L</service_path> attribute.
 
-=item B<has_service_path>
+=head2 C<get>
 
-=item B<is_locked>
+=head2 C<is_locked>
 
-=item B<lock>
+=head2 C<lock>
 
-=item B<service>
+=head2 C<unlock>
 
-=item B<service_name>
-
-=item B<service_path>
-
-=item B<unlock>
-
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+These methods are delegated to the L</service>.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
