@@ -2,7 +2,7 @@ package Bread::Board::LifeCycle::Singleton::WithParameters;
 BEGIN {
   $Bread::Board::LifeCycle::Singleton::WithParameters::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::LifeCycle::Singleton::WithParameters::VERSION = '0.32';
+$Bread::Board::LifeCycle::Singleton::WithParameters::VERSION = '0.33';
 use Moose::Role;
 
 with 'Bread::Board::LifeCycle';
@@ -62,39 +62,55 @@ Bread::Board::LifeCycle::Singleton::WithParameters
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
+Sub-role of L<Bread::Board::LifeCycle>, this role defines the
+"singleton" lifecycle for a parameterized service. The C<get> method
+will only do its work the first time it is invoked for each set of
+parameters; subsequent invocations with the same parameters will
+return the same object.
+
+=head1 ATTRIBUTES
+
+=head2 C<instances>
+
+Hashref mapping keys to objects, used to cache the results of L</get>
+
 =head1 METHODS
 
-=over 4
+=head2 C<get>
 
-=item B<get>
+Generates a key using L</generate_instance_key> (passing it all the
+arguments); if the L</instances> attribute does not hold an object for
+that key, it will build it (by calling the underlying C<get> method)
+and store it in L</instances>. The object (either retrieved from
+L</instances> or freshly built) will be returned.
 
-=item B<instance>
+=head2 C<generate_instance_key>
 
-=item B<has_instance>
-
-=item B<flush_instance>
-
-=item B<generate_instance_key>
-
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Generates a (hopefully) unique key from the given arguments (usually,
+whatever was passed to L</get>). The current implementation
+stringifies all arguments, so different references to identical values
+will be considered different.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
