@@ -2,7 +2,7 @@ package Bread::Board::Service;
 BEGIN {
   $Bread::Board::Service::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Service::VERSION = '0.32';
+$Bread::Board::Service::VERSION = '0.33';
 use Moose::Role;
 use Module::Runtime ();
 
@@ -129,47 +129,109 @@ Bread::Board::Service
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
+This role is the basis for all services in L<Bread::Board>. It
+provides (or requires the implementation of) the minimum necessary
+building blocks: creating an instance, setting/getting parameters,
+instance lifecycle.
+
+=head1 ATTRIBUTES
+
+=head2 C<name>
+
+Read/write string, required. Every service needs a name, by which it
+can be referenced when L<fetching it|Bread::Board::Traversable/fetch>.
+
+=head2 C<is_locked>
+
+Boolean, defaults to false. Used during L<dependency
+resolution|Bread::Board::Service::WithDependencies/resolve_dependencies>
+to detect loops.
+
+=head2 C<lifecycle>
+
+  $service->lifecycle('Singleton');
+
+Read/write string; it should be either a partial class name under the
+C<Bread::Board::LifeCycle::> namespace (like C<Singleton> for
+C<Bread::Board::LifeCycle::Singleton>) or a full class name prefixed
+with C<+> (like C<+My::Special::Lifecycle>). The name is expected to
+refer to a loadable I<role>, which will be applied to the service
+instance.
+
 =head1 METHODS
 
-=over 4
+=head2 C<lock>
 
-=item B<name>
+Locks the service; you should never need to call this method in normal
+code.
 
-=item B<is_locked>
+=head2 C<unlock>
 
-=item B<lock>
+Unlocks the service; you should never need to call this method in
+normal code.
 
-=item B<unlock>
+=head2 C<get>
 
-=item B<lifecycle>
+  my $value = $service->get();
 
-=item B<get>
+This method I<must> be implemented by the consuming class. It's
+expected to instantiate whatever object or value this service should
+resolve to.
 
-=item B<init_params>
+=head2 C<init_params>
 
-=item B<param>
+Builder for the service parameters, defaults to returning an empty
+hashref.
 
-=item B<clone_and_inherit_params>
+=head2 C<clear_params>
 
-=back
+Clearer of the service parameters.
 
-=head1 BUGS
+=head2 C<param>
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+  my @param_names = $service->param();
+  my $param_value = $service->param($param_name);
+  $service->param($name1=>$value1,$name2=>$value2);
+
+Getter/setter for the service parameters; notice that calling this
+method with no arguments returns the list of parameter names.
+
+I<Please note>: these are not the same as the L<parameters for a
+parametric service|Bread::Board::Service::WithParameters> (although
+those will be copied here before C<get> is called), nor are they the
+same thing as L<dependencies|Bread::Board::Service::WithDependencies>
+(although the resolved dependencies will be copied here before C<get>
+is called).
+
+=head2 C<clone_and_inherit_params>
+
+When declaring a service using the L<< C<service> helper
+function|Bread::Board/service >>, if the name you use starts with a
+C<'+'>, the service definition will extend an existing service with
+the given name (without the C<'+'>). This method implements the
+extension semantics: the C<dependencies> and C<parameters> options
+will be merged with the existing values, rather than overridden.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
