@@ -2,7 +2,7 @@ package Bread::Board::Service::Alias;
 BEGIN {
   $Bread::Board::Service::Alias::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Service::Alias::VERSION = '0.32';
+$Bread::Board::Service::Alias::VERSION = '0.33';
 use Moose;
 
 use Try::Tiny;
@@ -53,29 +53,43 @@ Bread::Board::Service::Alias
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
-No user servicable parts. Read the source if you are interested.
+This L<service|Bread::Board::Service> class implements
+L<aliases|Bread::Board/alias ($service_name, $service_path,
+%service_description)>.
 
-=head1 BUGS
+=head1 ATTRIBUTES
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+=head2 C<aliased_from_path>
 
-=for Pod::Coverage aliased_from_path
-aliased_from
-_build_aliased_from
+Read-only string attribute, the path of the service this alias refers
+to (it can be an alias itself)
+
+=head2 C<aliased_from>
+
+Lazy read-only attribute, built by calling L<<
+C<fetch>|Bread::Board::Traversable/fetch >> on this service using the
+L</aliased_from_path> as path to fetch
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
