@@ -2,7 +2,7 @@ package Bread::Board::Service::Deferred;
 BEGIN {
   $Bread::Board::Service::Deferred::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Service::Deferred::VERSION = '0.32';
+$Bread::Board::Service::Deferred::VERSION = '0.33';
 use Moose ();
 
 use overload
@@ -96,30 +96,41 @@ Bread::Board::Service::Deferred
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
-No user servicable parts. Read the source if you are interested.
+Class for proxy objects used when L<resolving circular
+dependencies|Bread::Board::Service::WithDependencies/resolve_dependencies>.
 
-=head1 BUGS
+This class uses a few nasty tricks: replacing C<$_[0]>, using
+C<AUTOLOAD>, overriding C<isa> C<meta> and C<can>, heavy operator
+overloading... you should probably not take inspiration from this code
+unless you really know what you're doing.
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+In practice, a variable containing an instance of
+C<Bread::Board::Service::Deferred> will have its value changed to the
+actual value instantiated by the service at the first opportunity, and
+you should not notice that this class was ever there.
 
-=for Pod::Coverage can
-isa
-meta
-new
+=for Pod::Coverage can isa meta new
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
