@@ -2,7 +2,7 @@ package Bread::Board::Service::Inferred;
 BEGIN {
   $Bread::Board::Service::Inferred::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Service::Inferred::VERSION = '0.31';
+$Bread::Board::Service::Inferred::VERSION = '0.33';
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
 
@@ -225,7 +225,7 @@ Bread::Board::Service::Inferred
 
 =head1 VERSION
 
-version 0.31
+version 0.33
 
 =head1 DESCRIPTION
 
@@ -235,25 +235,24 @@ Docs to come, as well as refactoring.
 
 =head1 METHODS
 
-=over 4
-
-=item B<infer_service>
-
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+=head2 C<infer_service>
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
