@@ -2,7 +2,7 @@ package Bread::Board::Service::WithClass;
 BEGIN {
   $Bread::Board::Service::WithClass::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Service::WithClass::VERSION = '0.32';
+$Bread::Board::Service::WithClass::VERSION = '0.33';
 use Moose::Role;
 use Module::Runtime ();
 
@@ -36,33 +36,47 @@ Bread::Board::Service::WithClass
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
+This a sub-role of L<Bread::Board::Service> for services that return
+instances of a given class.
+
+=head1 ATTRIBUTES
+
+=head2 C<class>
+
+Read/write string attribute, the name of the class that this service
+will probably instantiate.
+
 =head1 METHODS
 
-=over 4
+=head2 C<has_class>
 
-=item B<class>
+Predicate for the L</class> attribute, true if it has been set.
 
-=item B<get>
+=head2 C<get>
 
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+This role adds a C<before> modifier to the C<get> method, ensuring
+that the module implementing the L</class> is loaded.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
