@@ -2,7 +2,7 @@ package Bread::Board::Traversable;
 BEGIN {
   $Bread::Board::Traversable::AUTHORITY = 'cpan:STEVAN';
 }
-$Bread::Board::Traversable::VERSION = '0.32';
+$Bread::Board::Traversable::VERSION = '0.33';
 use Moose::Role;
 
 with 'MooseX::Clone' => { -version => 0.05 };
@@ -120,41 +120,76 @@ Bread::Board::Traversable
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
+  my $service = $container->fetch('/some/service/path');
+
+  my $root = $service->get_root_container;
+
 =head1 DESCRIPTION
 
+This role provides the basic functionality to traverse a container /
+service tree. Instances of classes consuming this role will get a
+parent-child relationship between them.
+
+=head1 ATTRIBUTES
+
+=head2 C<parent>
+
+Weak ref to another L<Bread::Board::Traversable> object, read/write
+accessor (although you should probably not change this value directly
+in normal code).
+
 =head1 METHODS
 
-=over 4
+=head2 C<has_parent>
 
-=item B<parent>
+Predicate for the L</parent> attribute, true if a parent has been set.
 
-=item B<has_parent>
+=head2 C<detach_from_parent>
 
-=item B<detach_from_parent>
+Clearer for the L</parent> attribute, you should probably not call
+this method in normal code.
 
-=item B<get_root_container>
+=head2 C<get_root_container>
 
-=item B<fetch>
+Returns the farthest ancestor of the invocant, i.e. the top-most
+container this object is a part of.
 
-=back
+=head2 C<fetch>
 
-=head1 BUGS
+  my $service = $this->fetch('/absolute/path');
+  my $service = $this->fetch('relative/path');
+  my $service = $this->fetch('../relative/path');
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Given a (relative or absolute) path to a service or container, this
+method walks the tree and returns the L<Bread::Board::Service> or
+L<Bread::Board::Container> instance for that path. Dies if no object
+can be found for the given
+path.
+
+L<Aliases|Bread::Board::Service::Alias> are resolved in this call, by
+calling L<< C<aliased_from>|Bread::Board::Service::Alias/aliased_from
+>> until we get an actual service.
 
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/stevan/BreadBoard/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive.
+This software is copyright (c) 2015 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
